@@ -35,7 +35,9 @@ fi
 
 # Detect Linux
 if [ "$UNAME_S" = "linux" ]
-	then TA="linux-$UNAME_M"
+	then
+	TA="linux-$UNAME_M"
+	[ ! -z "$ARCH" ] && TA="linux-$ARCH"
 	PKGTYPE=xz
 fi
 
@@ -64,6 +66,21 @@ make clean && make -j$PM ENABLE_DEDUPE=1 LOUD=1 stripped && cp $NAME$EXT $PKGNAM
 make clean && make -j$PM LOW_MEMORY=1 stripped && cp $NAME$EXT $PKGNAME/${NAME}-lowmem$EXT && E3=0
 make clean
 test $((E1 + E2 + E3)) -gt 0 && echo "Error building packages; aborting." && exit 1
+# Make a fat binary on macOS x86_64 if possible
+if [ "$TA" = "mac64" ] && ld -v 2>&1 | grep -q 'archs:.*i386'
+	then
+	E1=1; E2=1; E3=1
+	BITS=32
+	make clean && make -j$PM CFLAGS_EXTRA=-m32 stripped && cp $NAME$EXT $PKGNAME/$NAME$EXT$BITS && E1=0
+	make clean && make -j$PM CFLAGS_EXTRA=-m32 LOUD=1 stripped && cp $NAME$EXT $PKGNAME/$NAME-loud$EXT$BITS && E2=0
+	make clean && make -j$PM CFLAGS_EXTRA=-m32 LOW_MEMORY=1 stripped && cp $NAME$EXT $PKGNAME/${NAME}-lowmem${EXT}$BITS && E3=0
+	make clean
+	test $((E1 + E2 + E3)) -gt 0 && echo "Error building packages; aborting." && exit 1
+	test "$E1" = "0" && lipo -create -output $PKGNAME/jdupes_temp $PKGNAME/$NAME$EXT$BITS $PKGNAME/$NAME$EXT && mv $PKGNAME/jdupes_temp $PKGNAME/$NAME$EXT
+	test "$E2" = "0" && lipo -create -output $PKGNAME/jdupes_temp $PKGNAME/$NAME-loud$EXT$BITS $PKGNAME/$NAME-loud$EXT && mv $PKGNAME/jdupes_temp $PKGNAME/$NAME-loud$EXT
+	test "$E3" = "0" && lipo -create -output $PKGNAME/jdupes_temp $PKGNAME/$NAME-lowmem$EXT$BITS $PKGNAME/$NAME-lowmem$EXT && mv $PKGNAME/jdupes_temp $PKGNAME/$NAME-lowmem$EXT
+	rm -f $PKGNAME/$NAME$EXT$BITS $PKGNAME/$NAME-loud$EXT$BITS $PKGNAME/$NAME-lowmem$EXT$BITS
+fi
 test "$PKGTYPE" = "zip" && zip -9r $PKGNAME.zip $PKGNAME/
 test "$PKGTYPE" = "gz"  && tar -c $PKGNAME/ | gzip -9 > $PKGNAME.pkg.tar.gz
 test "$PKGTYPE" = "xz"  && tar -c $PKGNAME/ | xz -e > $PKGNAME.pkg.tar.xz
